#!/usr/bin/env python
from sys import argv
import sys
from anki.collection import Collection, ImportAnkiPackageRequest, ImportAnkiPackageOptions
import argparse

parser = argparse.ArgumentParser(
    prog="install_apkgs.py",
    description="Installs specified apks into the system collection")
parser.add_argument('-c', '--collection', help="path to system Anki data")
parser.add_argument('-a', '--apkg', required=True, action='append', help='An apkg to install')
parser.add_argument('-v', '--verbose', required=False, action='store_true', help='print the result of each import')

if __name__ == "__main__":
    args = parser.parse_args()
    global_col = Collection(path=args.collection)
    for apkg in args.apkg:
        if not apkg.endswith('.apkg'):
            raise Exception(f'{apkg} was given but is not an apkg')
    for apkg in args.apkg:
        changes = global_col.import_anki_package(ImportAnkiPackageRequest(
            package_path=apkg,
            options=ImportAnkiPackageOptions(
                merge_notetypes=True,
                update_notes=True,
                update_notetypes=True
            )
        )).log
        if args.verbose:
            print(f'{apkg}: {len(changes.new)} new, {len(changes.updated)} updated, {len(changes.conflicting)} conflicting, {len(changes.duplicate)} duplicates', file=sys.stderr)