PARCEL := node_modules/.bin/parcel
ESLINT := node_modules/.bin/eslint
JEST := node_modules/.bin/jest
TSC := node_modules/.bin/tsc
MARKDOWN_TO_HTML := node_modules/.bin/markdown-to-html
NODE_BINS := $(PARCEL) $(ESLINT) $(JEST) $(TSC) $(MARKDOWN_TO_HTML)

GEN_HANZI_DATA := $(BUILD_PREFIX)gen-hanzi-data/run
ANNOUNCE := $(BUILD_PREFIX)announce/run
BUILD_TS_SOURCES := $(shell find build -name '*.ts')
COMPILED_BUILD_BINS := $(GEN_HANZI_DATA) $(ANNOUNCE)
COMPILED_BUILD_JS := $(patsubst build/%.ts,$(BUILD_PREFIX)%.js, \
	$(BUILD_TS_SOURCES))
LINT_NODE_OK_FLAG := $(BUILD_PREFIX).lint-build-ok

MOSTLY_CLEAN += $(COMPILED_BUILD_JS) $(COMPILED_BUILD_BINS) $(LINT_NODE_OK_FLAG)
DEEP_CLEAN_DIRS += node_modules

.PHONY: node
node: $(NODE_BINS) $(COMPILED_BUILD_BINS)

.PHONY: lint-node
lint-node: $(LINT_NODE_OK_FLAG)

.PHONY: fix-node
fix-node: $(ESLINT) $(BUILD_TS_SOURCES)
	$(ESLINT) --fix $(BUILD_TS_SOURCES)

$(LINT_NODE_OK_FLAG): $(ESLINT) $(BUILD_TS_SOURCES)
	@$(and $(BUILD_PREFIX),mkdir -p $(BUILD_PREFIX))
	$(ESLINT) $(BUILD_TS_SOURCES)
	touch $(LINT_NODE_OK_FLAG)

yarn.lock $(NODE_BINS) &: package.json
	yarn install
	touch yarn.lock $(NODE_BINS)

$(COMPILED_BUILD_BINS): %: %.js
# prepend a shebang line and make executable
	echo "#!/usr/bin/env node" > $@
	cat $< >> $@
	chmod +x $@

$(COMPILED_BUILD_JS) &: $(TSC) $(BUILD_TS_SOURCES)
	@$(and $(BUILD_PREFIX),mkdir -p $(BUILD_PREFIX))
	$(TSC) -p build --outDir $(or $(BUILD_PREFIX),.)
	touch $(COMPILED_BUILD_JS)
